@@ -2,7 +2,7 @@
 /**
  * PHPUnit
  *
- * Copyright (c) 2002-2010, Sebastian Bergmann <sebastian@phpunit.de>.
+ * Copyright (c) 2001-2012, Sebastian Bergmann <sebastian@phpunit.de>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,7 +37,8 @@
  * @package    PHPUnit
  * @subpackage Framework_Constraint
  * @author     Sebastian Bergmann <sebastian@phpunit.de>
- * @copyright  2002-2010 Sebastian Bergmann <sebastian@phpunit.de>
+ * @author     Bernhard Schussek <bschussek@2bepublished.at>
+ * @copyright  2001-2012 Sebastian Bergmann <sebastian@phpunit.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
  * @link       http://www.phpunit.de/
  * @since      File available since Release 3.0.0
@@ -49,9 +50,10 @@
  * @package    PHPUnit
  * @subpackage Framework_Constraint
  * @author     Sebastian Bergmann <sebastian@phpunit.de>
- * @copyright  2002-2010 Sebastian Bergmann <sebastian@phpunit.de>
+ * @author     Bernhard Schussek <bschussek@2bepublished.at>
+ * @copyright  2001-2012 Sebastian Bergmann <sebastian@phpunit.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.5.5
+ * @version    Release: 3.6.10
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 3.0.0
  */
@@ -74,7 +76,7 @@ class PHPUnit_Framework_Constraint_And extends PHPUnit_Framework_Constraint
     {
         $this->constraints = array();
 
-        foreach($constraints as $key => $constraint) {
+        foreach ($constraints as $key => $constraint) {
             if (!($constraint instanceof PHPUnit_Framework_Constraint)) {
                 throw new InvalidArgumentException(
                   'All parameters to ' . __CLASS__ .
@@ -87,38 +89,40 @@ class PHPUnit_Framework_Constraint_And extends PHPUnit_Framework_Constraint
     }
 
     /**
-     * Evaluates the constraint for parameter $other. Returns TRUE if the
-     * constraint is met, FALSE otherwise.
+     * Evaluates the constraint for parameter $other
      *
-     * @param mixed $other Value or object to evaluate.
-     * @return bool
+     * If $returnResult is set to FALSE (the default), an exception is thrown
+     * in case of a failure. NULL is returned otherwise.
+     *
+     * If $returnResult is TRUE, the result of the evaluation is returned as
+     * a boolean value instead: TRUE in case of success, FALSE in case of a
+     * failure.
+     *
+     * @param  mixed $other Value or object to evaluate.
+     * @param  string $description Additional information about the test
+     * @param  bool $returnResult Whether to return a result or throw an exception
+     * @return mixed
+     * @throws PHPUnit_Framework_ExpectationFailedException
      */
-    public function evaluate($other)
+    public function evaluate($other, $description = '', $returnResult = FALSE)
     {
-        $this->lastConstraint = NULL;
+        $success = TRUE;
+        $constraint = NULL;
 
-        foreach($this->constraints as $constraint) {
-            $this->lastConstraint = $constraint;
-
-            if (!$constraint->evaluate($other)) {
-                return FALSE;
+        foreach ($this->constraints as $constraint) {
+            if (!$constraint->evaluate($other, $description, TRUE)) {
+                $success = FALSE;
+                break;
             }
         }
 
-        return TRUE;
-    }
+        if ($returnResult) {
+            return $success;
+        }
 
-    /**
-     * @param   mixed   $other The value passed to evaluate() which failed the
-     *                         constraint check.
-     * @param   string  $description A string with extra description of what was
-     *                               going on while the evaluation failed.
-     * @param   boolean $not Flag to indicate negation.
-     * @throws  PHPUnit_Framework_ExpectationFailedException
-     */
-    public function fail($other, $description, $not = FALSE)
-    {
-        $this->lastConstraint->fail($other, $description, $not);
+        if (!$success) {
+            $this->fail($other, $description);
+        }
     }
 
     /**
@@ -130,7 +134,7 @@ class PHPUnit_Framework_Constraint_And extends PHPUnit_Framework_Constraint
     {
         $text = '';
 
-        foreach($this->constraints as $key => $constraint) {
+        foreach ($this->constraints as $key => $constraint) {
             if ($key > 0) {
                 $text .= ' and ';
             }
