@@ -2,7 +2,7 @@
 /**
  * PHPUnit
  *
- * Copyright (c) 2002-2010, Sebastian Bergmann <sebastian@phpunit.de>.
+ * Copyright (c) 2001-2012, Sebastian Bergmann <sebastian@phpunit.de>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,7 +37,8 @@
  * @package    PHPUnit
  * @subpackage Framework_Constraint
  * @author     Sebastian Bergmann <sebastian@phpunit.de>
- * @copyright  2002-2010 Sebastian Bergmann <sebastian@phpunit.de>
+ * @author     Bernhard Schussek <bschussek@2bepublished.at>
+ * @copyright  2001-2012 Sebastian Bergmann <sebastian@phpunit.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
  * @link       http://www.phpunit.de/
  * @since      File available since Release 3.0.0
@@ -50,25 +51,38 @@
  * @package    PHPUnit
  * @subpackage Framework_Constraint
  * @author     Sebastian Bergmann <sebastian@phpunit.de>
- * @copyright  2002-2010 Sebastian Bergmann <sebastian@phpunit.de>
+ * @author     Bernhard Schussek <bschussek@2bepublished.at>
+ * @copyright  2001-2012 Sebastian Bergmann <sebastian@phpunit.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.5.5
+ * @version    Release: 3.6.10
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 3.0.0
  */
 class PHPUnit_Framework_Constraint_TraversableContains extends PHPUnit_Framework_Constraint
 {
+    /**
+     * @var boolean
+     */
+    protected $checkForObjectIdentity;
+
     /**
      * @var mixed
      */
     protected $value;
 
     /**
-     * @param mixed $value
+     * @param  boolean $value
+     * @param  mixed   $checkForObjectIdentity
+     * @throws InvalidArgumentException
      */
-    public function __construct($value)
+    public function __construct($value, $checkForObjectIdentity = TRUE)
     {
-        $this->value = $value;
+        if (!is_bool($checkForObjectIdentity)) {
+            throw PHPUnit_Util_InvalidArgumentHelper::factory(2, 'boolean');
+        }
+
+        $this->checkForObjectIdentity = $checkForObjectIdentity;
+        $this->value                  = $value;
     }
 
     /**
@@ -78,7 +92,7 @@ class PHPUnit_Framework_Constraint_TraversableContains extends PHPUnit_Framework
      * @param mixed $other Value or object to evaluate.
      * @return bool
      */
-    public function evaluate($other)
+    protected function matches($other)
     {
         if ($other instanceof SplObjectStorage) {
             return $other->contains($this->value);
@@ -86,7 +100,10 @@ class PHPUnit_Framework_Constraint_TraversableContains extends PHPUnit_Framework
 
         if (is_object($this->value)) {
             foreach ($other as $element) {
-                if ($element === $this->value) {
+                if (($this->checkForObjectIdentity &&
+                     $element === $this->value) ||
+                    (!$this->checkForObjectIdentity &&
+                     $element == $this->value)) {
                     return TRUE;
                 }
             }
@@ -111,14 +128,23 @@ class PHPUnit_Framework_Constraint_TraversableContains extends PHPUnit_Framework
         if (is_string($this->value) && strpos($this->value, "\n") !== FALSE) {
             return 'contains "' . $this->value . '"';
         } else {
-            return 'contains ' . PHPUnit_Util_Type::toString($this->value);
+            return 'contains ' . PHPUnit_Util_Type::export($this->value);
         }
     }
 
-    protected function customFailureDescription($other, $description, $not)
+    /**
+     * Returns the description of the failure
+     *
+     * The beginning of failure messages is "Failed asserting that" in most
+     * cases. This method should return the second part of that sentence.
+     *
+     * @param  mixed $other Evaluated value or object.
+     * @return string
+     */
+    protected function failureDescription($other)
     {
         return sprintf(
-          'Failed asserting that an %s %s.',
+          'an %s %s',
 
            is_array($other) ? 'array' : 'iterator',
            $this->toString()
