@@ -2,7 +2,7 @@
 /**
  * PHPUnit
  *
- * Copyright (c) 2002-2010, Sebastian Bergmann <sebastian@phpunit.de>.
+ * Copyright (c) 2001-2012, Sebastian Bergmann <sebastian@phpunit.de>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,14 +37,12 @@
  * @package    PHPUnit
  * @subpackage Framework
  * @author     Sebastian Bergmann <sebastian@phpunit.de>
- * @copyright  2002-2010 Sebastian Bergmann <sebastian@phpunit.de>
+ * @copyright  2001-2012 Sebastian Bergmann <sebastian@phpunit.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
  * @link       http://www.phpunit.de/
  * @since      File available since Release 2.0.0
  */
 
-require_once 'Text/Template.php';
-
 /**
  * A TestCase defines the fixture to run multiple tests.
  *
@@ -92,9 +90,9 @@ require_once 'Text/Template.php';
  * @package    PHPUnit
  * @subpackage Framework
  * @author     Sebastian Bergmann <sebastian@phpunit.de>
- * @copyright  2002-2010 Sebastian Bergmann <sebastian@phpunit.de>
+ * @copyright  2001-2012 Sebastian Bergmann <sebastian@phpunit.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.5.5
+ * @version    Release: 3.6.10
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 2.0.0
  */
@@ -105,12 +103,12 @@ abstract class PHPUnit_Framework_TestCase extends PHPUnit_Framework_Assert imple
      * Overwrite this attribute in a child class of TestCase.
      * Setting this attribute in setUp() has no effect!
      *
-     * @var    boolean
+     * @var boolean
      */
     protected $backupGlobals = NULL;
 
     /**
-     * @var    array
+     * @var array
      */
     protected $backupGlobalsBlacklist = array();
 
@@ -119,19 +117,19 @@ abstract class PHPUnit_Framework_TestCase extends PHPUnit_Framework_Assert imple
      * Overwrite this attribute in a child class of TestCase.
      * Setting this attribute in setUp() has no effect!
      *
-     * @var    boolean
+     * @var boolean
      */
     protected $backupStaticAttributes = NULL;
 
     /**
-     * @var    array
+     * @var array
      */
     protected $backupStaticAttributesBlacklist = array();
 
     /**
      * Whether or not this test is to be run in a separate PHP process.
      *
-     * @var    boolean
+     * @var boolean
      */
     protected $runTestInSeparateProcess = NULL;
 
@@ -139,131 +137,165 @@ abstract class PHPUnit_Framework_TestCase extends PHPUnit_Framework_Assert imple
      * Whether or not this test should preserve the global state when
      * running in a separate PHP process.
      *
-     * @var    boolean
+     * @var boolean
      */
     protected $preserveGlobalState = TRUE;
 
     /**
      * Whether or not this test is running in a separate PHP process.
      *
-     * @var    boolean
+     * @var boolean
      */
-    protected $inIsolation = FALSE;
+    private $inIsolation = FALSE;
 
     /**
-     * @var    array
+     * @var array
      */
-    protected $data = array();
+    private $data = array();
 
     /**
-     * @var    string
+     * @var string
      */
-    protected $dataName = '';
+    private $dataName = '';
 
     /**
-     * @var    boolean
+     * @var boolean
      */
-    protected $useErrorHandler = NULL;
+    private $useErrorHandler = NULL;
 
     /**
-     * @var    boolean
+     * @var boolean
      */
-    protected $useOutputBuffering = NULL;
+    private $useOutputBuffering = NULL;
 
     /**
      * The name of the expected Exception.
      *
-     * @var    mixed
+     * @var mixed
      */
-    protected $expectedException = NULL;
+    private $expectedException = NULL;
 
     /**
      * The message of the expected Exception.
      *
-     * @var    string
+     * @var string
      */
-    protected $expectedExceptionMessage = '';
+    private $expectedExceptionMessage = '';
 
     /**
      * The code of the expected Exception.
      *
-     * @var    integer
+     * @var integer
      */
-    protected $expectedExceptionCode;
+    private $expectedExceptionCode;
 
     /**
      * The stack trace to where the expected exception was set.
      *
-     * @var    array
+     * @var array
      */
-    protected $expectedExceptionTrace = array();
+    private $expectedExceptionTrace = array();
+
+    /**
+     * The required version of PHP.
+     *
+     * @var string
+     */
+    private $requiredPhp = '';
+
+    /**
+     * The required version of PHPUnit.
+     *
+     * @var string
+     */
+    private $requiredPhpUnit = '';
 
     /**
      * The name of the test case.
      *
-     * @var    string
+     * @var string
      */
-    protected $name = NULL;
+    private $name = NULL;
 
     /**
-     * @var    array
+     * @var array
      */
-    protected $dependencies = array();
+    private $dependencies = array();
 
     /**
-     * @var    array
+     * @var array
      */
-    protected $dependencyInput = array();
+    private $dependencyInput = array();
 
     /**
-     * @var    string
+     * @var array
      */
-    protected $exceptionMessage = NULL;
+    private $iniSettings = array();
 
     /**
-     * @var    integer
+     * @var array
      */
-    protected $exceptionCode = 0;
+    private $locale = array();
 
     /**
-     * @var    Array
+     * @var array
      */
-    protected $iniSettings = array();
+    private $mockObjects = array();
 
     /**
-     * @var    Array
+     * @var integer
      */
-    protected $locale = array();
+    private $status;
 
     /**
-     * @var    Array
+     * @var string
      */
-    protected $mockObjects = array();
+    private $statusMessage = '';
 
     /**
-     * @var    integer
+     * @var integer
      */
-    protected $status;
-
-    /**
-     * @var    string
-     */
-    protected $statusMessage = '';
-
-    /**
-     * @var    integer
-     */
-    protected $numAssertions = 0;
+    private $numAssertions = 0;
 
     /**
      * @var PHPUnit_Framework_TestResult
      */
-    protected $result;
+    private $result;
 
     /**
      * @var mixed
      */
-    protected $testResult;
+    private $testResult;
+
+    /**
+     * @var string
+     */
+    private $output = '';
+
+    /**
+     * @var string
+     */
+    private $outputExpectedRegex = NULL;
+
+    /**
+     * @var string
+     */
+    private $outputExpectedString = NULL;
+
+    /**
+     * @var bool
+     */
+    private $hasPerformedExpectationsOnOutput = FALSE;
+
+    /**
+     * @var mixed
+     */
+    private $outputCallback = FALSE;
+
+    /**
+     * @var boolean
+     */
+    private $outputBufferingActive = FALSE;
 
     /**
      * Constructs a test case with the given name.
@@ -339,6 +371,90 @@ abstract class PHPUnit_Framework_TestCase extends PHPUnit_Framework_Assert imple
         }
     }
 
+    /**
+     * Returns the size of the test.
+     *
+     * @return integer
+     * @since  Method available since Release 3.6.0
+     */
+    public function getSize()
+    {
+        return PHPUnit_Util_Test::getSize(
+          get_class($this), $this->getName(FALSE)
+        );
+    }
+
+    /**
+     * @return string
+     * @since  Method available since Release 3.6.0
+     */
+    public function getActualOutput()
+    {
+        if (!$this->outputBufferingActive) {
+            return $this->output;
+        } else {
+            return ob_get_contents();
+        }
+    }
+
+    /**
+     * @return string
+     * @since  Method available since Release 3.6.0
+     */
+    public function hasOutput()
+    {
+        if (empty($this->output)) {
+            return FALSE;
+        }
+
+        if ($this->outputExpectedString !== NULL ||
+            $this->outputExpectedRegex  !== NULL ||
+            $this->hasPerformedExpectationsOnOutput) {
+            return FALSE;
+        }
+
+        return TRUE;
+    }
+
+    /**
+     * @param string $expectedRegex
+     * @since Method available since Release 3.6.0
+     */
+    public function expectOutputRegex($expectedRegex)
+    {
+        if ($this->outputExpectedString !== NULL) {
+            throw new PHPUnit_Framework_Exception;
+        }
+
+        if (is_string($expectedRegex) || is_null($expectedRegex)) {
+            $this->outputExpectedRegex = $expectedRegex;
+        }
+    }
+
+    /**
+     * @param string $expectedString
+     * @since Method available since Release 3.6.0
+     */
+    public function expectOutputString($expectedString)
+    {
+        if ($this->outputExpectedRegex !== NULL) {
+            throw new PHPUnit_Framework_Exception;
+        }
+
+        if (is_string($expectedString) || is_null($expectedString)) {
+            $this->outputExpectedString = $expectedString;
+        }
+    }
+
+    /**
+     * @return bool
+     * @since Method available since Release 3.6.5
+     */
+    public function hasPerformedExpectationsOnOutput()
+    {
+        return $this->hasPerformedExpectationsOnOutput;
+    }
+
     /**
      * @return string
      * @since  Method available since Release 3.2.0
@@ -352,10 +468,17 @@ abstract class PHPUnit_Framework_TestCase extends PHPUnit_Framework_Assert imple
      * @param  mixed   $exceptionName
      * @param  string  $exceptionMessage
      * @param  integer $exceptionCode
+     * @throws InvalidArgumentException
      * @since  Method available since Release 3.2.0
      */
-    public function setExpectedException($exceptionName, $exceptionMessage = '', $exceptionCode = 0)
+    public function setExpectedException($exceptionName, $exceptionMessage = '', $exceptionCode = NULL)
     {
+        if ($exceptionName == 'Exception' || $exceptionName == '\\Exception') {
+            throw new InvalidArgumentException(
+              'You must not expect the generic exception class.'
+            );
+        }
+
         $this->expectedException        = $exceptionName;
         $this->expectedExceptionMessage = $exceptionMessage;
         $this->expectedExceptionCode    = $exceptionCode;
@@ -441,6 +564,58 @@ abstract class PHPUnit_Framework_TestCase extends PHPUnit_Framework_Assert imple
         }
     }
 
+    /**
+     * @since Method available since Release 3.6.0
+     */
+    protected function setRequirementsFromAnnotation()
+    {
+        try {
+            $requirements = PHPUnit_Util_Test::getRequirements(
+              get_class($this), $this->name
+            );
+
+            if (isset($requirements['PHP'])) {
+                $this->requiredPhp = $requirements['PHP'];
+            }
+
+            if (isset($requirements['PHPUnit'])) {
+                $this->requiredPhpUnit = $requirements['PHPUnit'];
+            }
+        }
+
+        catch (ReflectionException $e) {
+        }
+    }
+
+    /**
+     * @since Method available since Release 3.6.0
+     */
+    protected function checkRequirements()
+    {
+        $this->setRequirementsFromAnnotation();
+
+        if ($this->requiredPhp &&
+            version_compare(PHP_VERSION, $this->requiredPhp, '<')) {
+            $this->markTestSkipped(
+              sprintf(
+                'PHP %s (or later) is required.',
+                $this->requiredPhp
+              )
+            );
+        }
+
+        $phpunitVersion = PHPUnit_Runner_Version::id();
+        if ($this->requiredPhpUnit &&
+            version_compare($phpunitVersion, $this->requiredPhpUnit, '<')) {
+            $this->markTestSkipped(
+              sprintf(
+                'PHPUnit %s (or later) is required.',
+                $this->requiredPhpUnit
+              )
+            );
+        }
+    }
+
     /**
      * Returns the status of this test.
      *
@@ -491,11 +666,11 @@ abstract class PHPUnit_Framework_TestCase extends PHPUnit_Framework_Assert imple
             $result = $this->createResult();
         }
 
-        $this->result = $result;
-
-        $this->setExpectedExceptionFromAnnotation();
-        $this->setUseErrorHandlerFromAnnotation();
-        $this->setUseOutputBufferingFromAnnotation();
+        if (!$this instanceof PHPUnit_Framework_Warning) {
+            $this->setTestResultObject($result);
+            $this->setUseErrorHandlerFromAnnotation();
+            $this->setUseOutputBufferingFromAnnotation();
+        }
 
         if ($this->useErrorHandler !== NULL) {
             $oldErrorHandlerSetting = $result->getConvertErrorsToExceptions();
@@ -570,7 +745,8 @@ abstract class PHPUnit_Framework_TestCase extends PHPUnit_Framework_Assert imple
 
             $this->prepareTemplate($template);
 
-            PHPUnit_Util_PHP::runJob($template->render(), $this, $result);
+            $php = PHPUnit_Util_PHP::factory();
+            $php->runJob($template->render(), $this, $result);
         } else {
             $result->run($this);
         }
@@ -610,9 +786,8 @@ abstract class PHPUnit_Framework_TestCase extends PHPUnit_Framework_Assert imple
         }
 
         // Start output buffering.
-        if ($this->useOutputBuffering === TRUE) {
-            ob_start();
-        }
+        ob_start();
+        $this->outputBufferingActive = TRUE;
 
         // Clean up stat cache.
         clearstatcache();
@@ -622,7 +797,9 @@ abstract class PHPUnit_Framework_TestCase extends PHPUnit_Framework_Assert imple
                 $this->setUpBeforeClass();
             }
 
+            $this->setExpectedExceptionFromAnnotation();
             $this->setUp();
+            $this->checkRequirements();
             $this->assertPreConditions();
             $this->testResult = $this->runTest();
             $this->verifyMockObjects();
@@ -667,10 +844,17 @@ abstract class PHPUnit_Framework_TestCase extends PHPUnit_Framework_Assert imple
         }
 
         // Stop output buffering.
-        if ($this->useOutputBuffering === TRUE) {
-            ob_end_clean();
+        if ($this->outputCallback === FALSE) {
+            $this->output = ob_get_contents();
+        } else {
+            $this->output = call_user_func_array(
+              $this->outputCallback, array(ob_get_contents())
+            );
         }
 
+        ob_end_clean();
+        $this->outputBufferingActive = FALSE;
+
         // Clean up stat cache.
         clearstatcache();
 
@@ -702,6 +886,27 @@ abstract class PHPUnit_Framework_TestCase extends PHPUnit_Framework_Assert imple
             setlocale($category, $locale);
         }
 
+        // Perform assertion on output.
+        if (!isset($e)) {
+            try {
+                if ($this->outputExpectedRegex !== NULL) {
+                    $this->hasPerformedExpectationsOnOutput = TRUE;
+                    $this->assertRegExp($this->outputExpectedRegex, $this->output);
+                    $this->outputExpectedRegex = NULL;
+                }
+
+                else if ($this->outputExpectedString !== NULL) {
+                    $this->hasPerformedExpectationsOnOutput = TRUE;
+                    $this->assertEquals($this->outputExpectedString, $this->output);
+                    $this->outputExpectedString = NULL;
+                }
+            }
+
+            catch (Exception $_e) {
+                $e = $_e;
+            }
+        }
+
         // Workaround for missing "finally".
         if (isset($e)) {
             $this->onNotSuccessfulTest($e);
@@ -740,25 +945,33 @@ abstract class PHPUnit_Framework_TestCase extends PHPUnit_Framework_Assert imple
         catch (Exception $e) {
             if (!$e instanceof PHPUnit_Framework_IncompleteTest &&
                 !$e instanceof PHPUnit_Framework_SkippedTest &&
-                is_string($this->expectedException) &&
-                $e instanceof $this->expectedException) {
+                is_string($this->expectedException)) {
+                $this->assertThat(
+                  $e,
+                  new PHPUnit_Framework_Constraint_Exception(
+                    $this->expectedException
+                  )
+                );
+
                 if (is_string($this->expectedExceptionMessage) &&
                     !empty($this->expectedExceptionMessage)) {
-                    $this->assertContains(
-                      $this->expectedExceptionMessage,
-                      $e->getMessage()
+                    $this->assertThat(
+                      $e,
+                      new PHPUnit_Framework_Constraint_ExceptionMessage(
+                        $this->expectedExceptionMessage
+                      )
                     );
                 }
 
-                if (is_int($this->expectedExceptionCode) &&
-                    $this->expectedExceptionCode !== 0) {
-                    $this->assertEquals(
-                      $this->expectedExceptionCode, $e->getCode()
+                if ($this->expectedExceptionCode !== NULL) {
+                    $this->assertThat(
+                      $e,
+                      new PHPUnit_Framework_Constraint_ExceptionCode(
+                        $this->expectedExceptionCode
+                      )
                     );
                 }
 
-                $this->numAssertions++;
-
                 return;
             } else {
                 throw $e;
@@ -766,13 +979,11 @@ abstract class PHPUnit_Framework_TestCase extends PHPUnit_Framework_Assert imple
         }
 
         if ($this->expectedException !== NULL) {
-            $this->numAssertions++;
-
-            $this->syntheticFail(
-              'Expected exception ' . $this->expectedException,
-              '',
-              0,
-              $this->expectedExceptionTrace
+            $this->assertThat(
+              NULL,
+              new PHPUnit_Framework_Constraint_Exception(
+                $this->expectedException
+              )
             );
         }
 
@@ -787,7 +998,10 @@ abstract class PHPUnit_Framework_TestCase extends PHPUnit_Framework_Assert imple
     protected function verifyMockObjects()
     {
         foreach ($this->mockObjects as $mockObject) {
-            $this->numAssertions++;
+            if ($mockObject->__phpunit_hasMatchers()) {
+                $this->numAssertions++;
+            }
+
             $mockObject->__phpunit_verify();
             $mockObject->__phpunit_cleanup();
         }
@@ -916,6 +1130,37 @@ abstract class PHPUnit_Framework_TestCase extends PHPUnit_Framework_Assert imple
         $this->testResult = $result;
     }
 
+    /**
+     * @param callable $callback
+     * @since Method available since Release 3.6.0
+     */
+    public function setOutputCallback($callback)
+    {
+        if (!is_callable($callback)) {
+            throw PHPUnit_Util_InvalidArgumentHelper::factory(1, 'callback');
+        }
+
+        $this->outputCallback = $callback;
+    }
+
+    /**
+     * @return PHPUnit_Framework_TestResult
+     * @since  Method available since Release 3.5.7
+     */
+    public function getTestResultObject()
+    {
+        return $this->result;
+    }
+
+    /**
+     * @param PHPUnit_Framework_TestResult $result
+     * @since Method available since Release 3.6.0
+     */
+    public function setTestResultObject(PHPUnit_Framework_TestResult $result)
+    {
+        $this->result = $result;
+    }
+
     /**
      * This method is a wrapper for the ini_set() function that automatically
      * resets the modified php.ini setting to its original value after the
@@ -1074,7 +1319,8 @@ abstract class PHPUnit_Framework_TestCase extends PHPUnit_Framework_Assert imple
 
     /**
      * Returns a mock object for the specified abstract class with all abstract
-     * methods of the class mocked. Concrete methods are not mocked.
+     * methods of the class mocked. Concrete methods to mock can be specified with
+     * the last parameter
      *
      * @param  string  $originalClassName
      * @param  array   $arguments
@@ -1082,11 +1328,12 @@ abstract class PHPUnit_Framework_TestCase extends PHPUnit_Framework_Assert imple
      * @param  boolean $callOriginalConstructor
      * @param  boolean $callOriginalClone
      * @param  boolean $callAutoload
+     * @param  array   $mockedMethods
      * @return PHPUnit_Framework_MockObject_MockObject
      * @since  Method available since Release 3.4.0
      * @throws InvalidArgumentException
      */
-    public function getMockForAbstractClass($originalClassName, array $arguments = array(), $mockClassName = '', $callOriginalConstructor = TRUE, $callOriginalClone = TRUE, $callAutoload = TRUE)
+    public function getMockForAbstractClass($originalClassName, array $arguments = array(), $mockClassName = '', $callOriginalConstructor = TRUE, $callOriginalClone = TRUE, $callAutoload = TRUE, $mockedMethods = array())
     {
         $mockObject = PHPUnit_Framework_MockObject_Generator::getMockForAbstractClass(
           $originalClassName,
@@ -1094,7 +1341,8 @@ abstract class PHPUnit_Framework_TestCase extends PHPUnit_Framework_Assert imple
           $mockClassName,
           $callOriginalConstructor,
           $callOriginalClone,
-          $callAutoload
+          $callAutoload,
+          $mockedMethods
         );
 
         $this->mockObjects[] = $mockObject;
@@ -1138,6 +1386,31 @@ abstract class PHPUnit_Framework_TestCase extends PHPUnit_Framework_Assert imple
         );
     }
 
+    /**
+     * Returns an object for the specified trait.
+     *
+     * @param  string  $traitName
+     * @param  array   $arguments
+     * @param  string  $traitClassName
+     * @param  boolean $callOriginalConstructor
+     * @param  boolean $callOriginalClone
+     * @param  boolean $callAutoload
+     * @return object
+     * @since  Method available since Release 3.6.0
+     * @throws InvalidArgumentException
+     */
+    protected function getObjectForTrait($traitName, array $arguments = array(), $traitClassName = '', $callOriginalConstructor = TRUE, $callOriginalClone = TRUE, $callAutoload = TRUE)
+    {
+        return PHPUnit_Framework_MockObject_Generator::getObjectForTrait(
+          $traitName,
+          $arguments,
+          $traitClassName,
+          $callOriginalConstructor,
+          $callOriginalClone,
+          $callAutoload
+        );
+    }
+
     /**
      * Adds a value to the assertion counter.
      *
@@ -1246,6 +1519,18 @@ abstract class PHPUnit_Framework_TestCase extends PHPUnit_Framework_Assert imple
         return new PHPUnit_Framework_MockObject_Stub_Return($value);
     }
 
+    /**
+     *
+     *
+     * @param  array $valueMap
+     * @return PHPUnit_Framework_MockObject_Stub_ReturnValueMap
+     * @since  Method available since Release 3.6.0
+     */
+    public static function returnValueMap(array $valueMap)
+    {
+        return new PHPUnit_Framework_MockObject_Stub_ReturnValueMap($valueMap);
+    }
+
     /**
      *
      *
@@ -1272,6 +1557,19 @@ abstract class PHPUnit_Framework_TestCase extends PHPUnit_Framework_Assert imple
         return new PHPUnit_Framework_MockObject_Stub_ReturnCallback($callback);
     }
 
+    /**
+     * Returns the current object.
+     *
+     * This method is useful when mocking a fluent interface.
+     *
+     * @return PHPUnit_Framework_MockObject_Stub_ReturnSelf
+     * @since  Method available since Release 3.6.0
+     */
+    public static function returnSelf()
+    {
+        return new PHPUnit_Framework_MockObject_Stub_ReturnSelf();
+    }
+
     /**
      *
      *
@@ -1307,8 +1605,26 @@ abstract class PHPUnit_Framework_TestCase extends PHPUnit_Framework_Assert imple
     {
         $result = array();
 
-        foreach ($data as $_data) {
-            if (is_array($_data)) {
+        // There seems to be no other way to check arrays for recursion
+        // http://www.php.net/manual/en/language.types.array.php#73936
+        preg_match_all('/\n            \[(\w+)\] => Array\s+\*RECURSION\*/', print_r($data, TRUE), $matches);
+        $recursiveKeys = array_unique($matches[1]);
+
+        // Convert to valid array keys
+        // Numeric integer strings are automatically converted to integers
+        // by PHP
+        foreach ($recursiveKeys as $key => $recursiveKey) {
+            if ((string)(integer)$recursiveKey === $recursiveKey) {
+                $recursiveKeys[$key] = (integer)$recursiveKey;
+            }
+        }
+
+        foreach ($data as $key => $_data) {
+            if (in_array($key, $recursiveKeys, TRUE)) {
+                $result[] = '*RECURSION*';
+            }
+
+            else if (is_array($_data)) {
                 $result[] = 'array(' . $this->dataToString($_data) . ')';
             }
 
@@ -1408,12 +1724,24 @@ abstract class PHPUnit_Framework_TestCase extends PHPUnit_Framework_Assert imple
                     );
 
                     return FALSE;
-                } else {
-                    if (isset($passed[$dependency])) {
-                        $this->dependencyInput[] = $passed[$dependency];
-                    } else {
-                        $this->dependencyInput[] = NULL;
+                }
+
+                if (isset($passed[$dependency])) {
+                    if ($passed[$dependency]['size'] > $this->getSize()) {
+                        $this->result->addError(
+                          $this,
+                          new PHPUnit_Framework_SkippedTestError(
+                            'This test depends on a test that is larger than itself.'
+                          ),
+                          0
+                        );
+
+                        return FALSE;
                     }
+
+                    $this->dependencyInput[] = $passed[$dependency]['result'];
+                } else {
+                    $this->dependencyInput[] = NULL;
                 }
             }
         }
