@@ -2,7 +2,7 @@
 /**
  * PHPUnit
  *
- * Copyright (c) 2002-2010, Sebastian Bergmann <sebastian@phpunit.de>.
+ * Copyright (c) 2001-2012, Sebastian Bergmann <sebastian@phpunit.de>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,24 +37,21 @@
  * @package    PHPUnit
  * @subpackage Framework
  * @author     Sebastian Bergmann <sebastian@phpunit.de>
- * @copyright  2002-2010 Sebastian Bergmann <sebastian@phpunit.de>
+ * @copyright  2001-2012 Sebastian Bergmann <sebastian@phpunit.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
  * @link       http://www.phpunit.de/
  * @since      File available since Release 2.0.0
  */
 
-require_once 'PHP/CodeCoverage.php';
-require_once 'PHP/Timer.php';
-
 /**
  * A TestResult collects the results of executing a test case.
  *
  * @package    PHPUnit
  * @subpackage Framework
  * @author     Sebastian Bergmann <sebastian@phpunit.de>
- * @copyright  2002-2010 Sebastian Bergmann <sebastian@phpunit.de>
+ * @copyright  2001-2012 Sebastian Bergmann <sebastian@phpunit.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.5.5
+ * @version    Release: 3.6.10
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 2.0.0
  */
@@ -80,6 +77,11 @@ class PHPUnit_Framework_TestResult implements Countable
      */
     protected $errors = array();
 
+    /**
+     * @var array
+     */
+    protected $deprecatedFeatures = array();
+
     /**
      * @var array
      */
@@ -118,25 +120,10 @@ class PHPUnit_Framework_TestResult implements Countable
     /**
      * Code Coverage information.
      *
-     * @var array
+     * @var PHP_CodeCoverage
      */
     protected $codeCoverage;
 
-    /**
-     * @var boolean
-     */
-    protected $collectCodeCoverageInformation = FALSE;
-
-    /**
-     * @var boolean
-     */
-    protected $collectRawCodeCoverageInformation = FALSE;
-
-    /**
-     * @var array
-     */
-    protected $rawCodeCoverageInformation = array();
-
     /**
      * @var boolean
      */
@@ -178,16 +165,19 @@ class PHPUnit_Framework_TestResult implements Countable
     protected $lastTestFailed = FALSE;
 
     /**
-     * @param PHP_CodeCoverage $codeCoverage
+     * @var integer
      */
-    public function __construct(PHP_CodeCoverage $codeCoverage = NULL)
-    {
-        if ($codeCoverage === NULL) {
-            $codeCoverage = PHP_CodeCoverage::getInstance();
-        }
+    protected $timeoutForSmallTests = 1;
 
-        $this->codeCoverage = $codeCoverage;
-    }
+    /**
+     * @var integer
+     */
+    protected $timeoutForMediumTests = 10;
+
+    /**
+     * @var integer
+     */
+    protected $timeoutForLargeTests = 60;
 
     /**
      * Registers a TestListener.
@@ -322,6 +312,16 @@ class PHPUnit_Framework_TestResult implements Countable
         $this->time          += $time;
     }
 
+    /**
+     * Adds a deprecated feature notice to the list of deprecated features used during run
+     *
+     * @param PHPUnit_Util_DeprecatedFeature $deprecatedFeature
+     */
+    public function addDeprecatedFeature(PHPUnit_Util_DeprecatedFeature $deprecatedFeature)
+    {
+        $this->deprecatedFeatures[] = $deprecatedFeature;
+    }
+
     /**
      * Informs the result that a testsuite will be started.
      *
@@ -380,8 +380,17 @@ class PHPUnit_Framework_TestResult implements Countable
         }
 
         if (!$this->lastTestFailed && $test instanceof PHPUnit_Framework_TestCase) {
-            $this->passed[get_class($test) . '::' . $test->getName()] = $test->getResult();
-            $this->time                                              += $time;
+            $class  = get_class($test);
+            $key    =  $class . '::' . $test->getName();
+
+            $this->passed[$key] = array(
+              'result' => $test->getResult(),
+              'size'   => PHPUnit_Util_Test::getSize(
+                            $class, $test->getName(FALSE)
+                          )
+            );
+
+            $this->time += $time;
         }
     }
 
@@ -468,6 +477,28 @@ class PHPUnit_Framework_TestResult implements Countable
         return $this->errors;
     }
 
+    /**
+     * Returns an Enumeration for the deprecated features used.
+     *
+     * @return array
+     * @since  Method available since Release 3.5.7
+     */
+    public function deprecatedFeatures()
+    {
+        return $this->deprecatedFeatures;
+    }
+
+    /**
+     * Returns an Enumeration for the deprecated features used.
+     *
+     * @return array
+     * @since  Method available since Release 3.5.7
+     */
+    public function deprecatedFeaturesCount()
+    {
+        return count($this->deprecatedFeatures);
+    }
+
     /**
      * Gets the number of detected failures.
      *
@@ -510,42 +541,6 @@ class PHPUnit_Framework_TestResult implements Countable
         return $this->topTestSuite;
     }
 
-    /**
-     * Enables or disables the collection of Code Coverage information.
-     *
-     * @param  boolean $flag
-     * @throws InvalidArgumentException
-     * @since  Method available since Release 2.3.0
-     */
-    public function collectCodeCoverageInformation($flag)
-    {
-        if (is_bool($flag)) {
-            $this->collectCodeCoverageInformation = $flag;
-        } else {
-            throw PHPUnit_Util_InvalidArgumentHelper::factory(1, 'boolean');
-        }
-    }
-
-    /**
-     * Enables or disables the collection of raw Code Coverage information.
-     *
-     * @param  boolean $flag
-     * @throws InvalidArgumentException
-     * @since  Method available since Release 3.4.0
-     */
-    public function collectRawCodeCoverageInformation($flag)
-    {
-        if (is_bool($flag)) {
-            $this->collectRawCodeCoverageInformation = $flag;
-
-            if ($flag === TRUE) {
-                $this->collectCodeCoverageInformation = $flag;
-            }
-        } else {
-            throw PHPUnit_Util_InvalidArgumentHelper::factory(1, 'boolean');
-        }
-    }
-
     /**
      * Returns whether code coverage information should be collected.
      *
@@ -554,18 +549,7 @@ class PHPUnit_Framework_TestResult implements Countable
      */
     public function getCollectCodeCoverageInformation()
     {
-        return $this->collectCodeCoverageInformation;
-    }
-
-    /**
-     * Returns the raw Code Coverage information.
-     *
-     * @return array
-     * @since  Method available since Release 3.4.0
-     */
-    public function getRawCodeCoverageInformation()
-    {
-        return $this->rawCodeCoverageInformation;
+        return $this->codeCoverage !== NULL;
     }
 
     /**
@@ -615,18 +599,55 @@ class PHPUnit_Framework_TestResult implements Countable
         }
 
         $useXdebug = self::$useXdebug &&
-                     $this->collectCodeCoverageInformation &&
+                     $this->codeCoverage !== NULL &&
                      !$test instanceof PHPUnit_Extensions_SeleniumTestCase &&
                      !$test instanceof PHPUnit_Framework_Warning;
 
         if ($useXdebug) {
+            // We need to blacklist test source files when no whitelist is used.
+            if (!$this->codeCoverage->filter()->hasWhitelist()) {
+                $classes = PHPUnit_Util_Class::getHierarchy(
+                  get_class($test), TRUE
+                );
+
+                foreach ($classes as $class) {
+                    $this->codeCoverage->filter()->addFileToBlacklist(
+                      $class->getFileName()
+                    );
+                }
+            }
+
             $this->codeCoverage->start($test);
         }
 
         PHP_Timer::start();
 
         try {
-            $test->runBare();
+            if (!$test instanceof PHPUnit_Framework_Warning &&
+                $this->strictMode &&
+                extension_loaded('pcntl') && class_exists('PHP_Invoker')) {
+                switch ($test->getSize()) {
+                    case PHPUnit_Util_Test::SMALL: {
+                        $_timeout = $this->timeoutForSmallTests;
+                    }
+                    break;
+
+                    case PHPUnit_Util_Test::MEDIUM: {
+                        $_timeout = $this->timeoutForMediumTests;
+                    }
+                    break;
+
+                    case PHPUnit_Util_Test::LARGE: {
+                        $_timeout = $this->timeoutForLargeTests;
+                    }
+                    break;
+                }
+
+                $invoker = new PHP_Invoker;
+                $invoker->invoke(array($test, 'runBare'), array(), $_timeout);
+            } else {
+                $test->runBare();
+            }
         }
 
         catch (PHPUnit_Framework_AssertionFailedError $e) {
@@ -646,33 +667,30 @@ class PHPUnit_Framework_TestResult implements Countable
         }
 
         $time = PHP_Timer::stop();
+        $test->addToAssertionCount(PHPUnit_Framework_Assert::getCount());
+
+        if ($this->strictMode && $test->getNumAssertions() == 0) {
+            $incomplete = TRUE;
+        }
 
         if ($useXdebug) {
-            $data = $this->codeCoverage->stop(FALSE);
-
-            if (!$this->strictMode || (!$incomplete && !$skipped)) {
-                if ($this->collectRawCodeCoverageInformation) {
-                    $this->rawCodeCoverageInformation[] = $data;
-                } else {
-                    $filterGroups = array('DEFAULT', 'TESTS');
-
-                    if (!defined('PHPUNIT_TESTSUITE')) {
-                        $filterGroups[] = 'PHPUNIT';
-                    }
-
-                    $this->codeCoverage->append($data, $test, $filterGroups);
-                }
+            try {
+                $this->codeCoverage->stop(!$incomplete && !$skipped);
             }
 
-            unset($data);
+            catch (PHP_CodeCoverage_Exception $cce) {
+                $error = TRUE;
+
+                if (!isset($e)) {
+                    $e = $cce;
+                }
+            }
         }
 
         if ($errorHandlerSet === TRUE) {
             restore_error_handler();
         }
 
-        $test->addToAssertionCount(PHPUnit_Framework_Assert::getCount());
-
         if ($error === TRUE) {
             $this->addError($test, $e, $time);
         }
@@ -691,6 +709,19 @@ class PHPUnit_Framework_TestResult implements Countable
             );
         }
 
+        else if ($this->strictMode && $test->hasOutput()) {
+            $this->addFailure(
+              $test,
+              new PHPUnit_Framework_OutputError(
+                sprintf(
+                  'This test printed output: %s',
+                  $test->getActualOutput()
+                )
+              ),
+              $time
+            );
+        }
+
         $this->endTest($test, $time);
     }
 
@@ -734,6 +765,17 @@ class PHPUnit_Framework_TestResult implements Countable
         return $this->codeCoverage;
     }
 
+    /**
+     * Returns the PHP_CodeCoverage object.
+     *
+     * @return PHP_CodeCoverage
+     * @since  Method available since Release 3.6.0
+     */
+    public function setCodeCoverage(PHP_CodeCoverage $codeCoverage)
+    {
+        $this->codeCoverage = $codeCoverage;
+    }
+
     /**
      * Enables or disables the error-to-exception conversion.
      *
@@ -864,4 +906,52 @@ class PHPUnit_Framework_TestResult implements Countable
     {
         return empty($this->errors) && empty($this->failures);
     }
+
+    /**
+     * Sets the timeout for small tests.
+     *
+     * @param  integer $timeout
+     * @throws InvalidArgumentException
+     * @since  Method available since Release 3.6.0
+     */
+    public function setTimeoutForSmallTests($timeout)
+    {
+        if (is_integer($timeout)) {
+            $this->timeoutForSmallTests = $timeout;
+        } else {
+            throw PHPUnit_Util_InvalidArgumentHelper::factory(1, 'integer');
+        }
+    }
+
+    /**
+     * Sets the timeout for medium tests.
+     *
+     * @param  integer $timeout
+     * @throws InvalidArgumentException
+     * @since  Method available since Release 3.6.0
+     */
+    public function setTimeoutForMediumTests($timeout)
+    {
+        if (is_integer($timeout)) {
+            $this->timeoutForMediumTests = $timeout;
+        } else {
+            throw PHPUnit_Util_InvalidArgumentHelper::factory(1, 'integer');
+        }
+    }
+
+    /**
+     * Sets the timeout for large tests.
+     *
+     * @param  integer $timeout
+     * @throws InvalidArgumentException
+     * @since  Method available since Release 3.6.0
+     */
+    public function setTimeoutForLargeTests($timeout)
+    {
+        if (is_integer($timeout)) {
+            $this->timeoutForLargeTests = $timeout;
+        } else {
+            throw PHPUnit_Util_InvalidArgumentHelper::factory(1, 'integer');
+        }
+    }
 }
