@@ -2,7 +2,7 @@
 /**
  * PHPUnit
  *
- * Copyright (c) 2002-2010, Sebastian Bergmann <sebastian@phpunit.de>.
+ * Copyright (c) 2001-2012, Sebastian Bergmann <sebastian@phpunit.de>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,7 +37,7 @@
  * @package    PHPUnit
  * @subpackage TextUI
  * @author     Sebastian Bergmann <sebastian@phpunit.de>
- * @copyright  2002-2010 Sebastian Bergmann <sebastian@phpunit.de>
+ * @copyright  2001-2012 Sebastian Bergmann <sebastian@phpunit.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
  * @link       http://www.phpunit.de/
  * @since      File available since Release 2.0.0
@@ -50,9 +50,9 @@
  * @package    PHPUnit
  * @subpackage TextUI
  * @author     Sebastian Bergmann <sebastian@phpunit.de>
- * @copyright  2002-2010 Sebastian Bergmann <sebastian@phpunit.de>
+ * @copyright  2001-2012 Sebastian Bergmann <sebastian@phpunit.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.5.5
+ * @version    Release: 3.6.10
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 2.0.0
  */
@@ -63,27 +63,38 @@ class PHPUnit_TextUI_TestRunner extends PHPUnit_Runner_BaseTestRunner
     const EXCEPTION_EXIT = 2;
 
     /**
-     * @var    PHPUnit_Runner_TestSuiteLoader
+     * @var PHP_CodeCoverage_Filter
+     */
+    protected $codeCoverageFilter;
+
+    /**
+     * @var PHPUnit_Runner_TestSuiteLoader
      */
     protected $loader = NULL;
 
     /**
-     * @var    PHPUnit_TextUI_ResultPrinter
+     * @var PHPUnit_TextUI_ResultPrinter
      */
     protected $printer = NULL;
 
     /**
-     * @var    boolean
+     * @var boolean
      */
     protected static $versionStringPrinted = FALSE;
 
     /**
-     * @param  PHPUnit_Runner_TestSuiteLoader $loader
-     * @since  Method available since Release 3.4.0
+     * @param PHPUnit_Runner_TestSuiteLoader $loader
+     * @param PHP_CodeCoverage_Filter        $filter
+     * @since Method available since Release 3.4.0
      */
-    public function __construct(PHPUnit_Runner_TestSuiteLoader $loader = NULL)
+    public function __construct(PHPUnit_Runner_TestSuiteLoader $loader = NULL, PHP_CodeCoverage_Filter $filter = NULL)
     {
-        $this->loader = $loader;
+        if ($filter === NULL) {
+            $filter = new PHP_CodeCoverage_Filter;
+        }
+
+        $this->codeCoverageFilter = $filter;
+        $this->loader             = $loader;
     }
 
     /**
@@ -111,24 +122,6 @@ class PHPUnit_TextUI_TestRunner extends PHPUnit_Runner_BaseTestRunner
         }
     }
 
-    /**
-     * Runs a single test and waits until the user types RETURN.
-     *
-     * @param  PHPUnit_Framework_Test $suite
-     */
-    public static function runAndWait(PHPUnit_Framework_Test $suite)
-    {
-        $aTestRunner = new PHPUnit_TextUI_TestRunner;
-
-        $aTestRunner->doRun(
-          $suite,
-          array(
-            'wait' => TRUE
-          )
-        );
-
-    }
-
     /**
      * @return PHPUnit_Framework_TestResult
      */
@@ -147,11 +140,7 @@ class PHPUnit_TextUI_TestRunner extends PHPUnit_Runner_BaseTestRunner
         $this->handleConfiguration($arguments);
 
         if (isset($arguments['bootstrap'])) {
-            $bootstrap = PHPUnit_Util_Fileloader::load($arguments['bootstrap']);
-
-            if ($bootstrap) {
-                $GLOBALS['__PHPUNIT_BOOTSTRAP'] = $bootstrap;
-            }
+            $GLOBALS['__PHPUNIT_BOOTSTRAP'] = $arguments['bootstrap'];
         }
 
         if ($arguments['backupGlobals'] === FALSE) {
@@ -222,6 +211,15 @@ class PHPUnit_TextUI_TestRunner extends PHPUnit_Runner_BaseTestRunner
             $this->printer->write(
               PHPUnit_Runner_Version::getVersionString() . "\n\n"
             );
+
+            if (isset($arguments['configuration'])) {
+                $this->printer->write(
+                  sprintf(
+                    "Configuration read from %s\n\n",
+                    $arguments['configuration']->getFilename()
+                  )
+                );
+            }
         }
 
         foreach ($arguments['listeners'] as $listener) {
@@ -230,20 +228,8 @@ class PHPUnit_TextUI_TestRunner extends PHPUnit_Runner_BaseTestRunner
 
         $result->addListener($this->printer);
 
-        if (isset($arguments['storyHTMLFile'])) {
-            $result->addListener(
-              new PHPUnit_Extensions_Story_ResultPrinter_HTML(
-                $arguments['storyHTMLFile']
-              )
-            );
-        }
-
-        if (isset($arguments['storyTextFile'])) {
-            $result->addListener(
-              new PHPUnit_Extensions_Story_ResultPrinter_Text(
-                $arguments['storyTextFile']
-              )
-            );
+        if ($this->printer instanceof PHPUnit_TextUI_ResultPrinter) {
+            $result->addListener(new PHPUnit_Util_DeprecatedFeature_Logger);
         }
 
         if (isset($arguments['testdoxHTMLFile'])) {
@@ -263,13 +249,35 @@ class PHPUnit_TextUI_TestRunner extends PHPUnit_Runner_BaseTestRunner
         }
 
         if ((isset($arguments['coverageClover']) ||
-             isset($arguments['reportDirectory'])) &&
+             isset($arguments['reportDirectory']) ||
+             isset($arguments['coveragePHP']) ||
+             isset($arguments['coverageText'])) &&
              extension_loaded('xdebug')) {
-            $result->collectCodeCoverageInformation(TRUE);
-        }
+            $codeCoverage = new PHP_CodeCoverage(
+              NULL, $this->codeCoverageFilter
+            );
 
-        if (isset($arguments['logDbus'])) {
-            $result->addListener(new PHPUnit_Util_Log_DBUS);
+            $codeCoverage->setProcessUncoveredFilesFromWhitelist(
+              $arguments['addUncoveredFilesFromWhitelist']
+            );
+
+            if (isset($arguments['cacheTokens'])) {
+                $codeCoverage->setCacheTokens($arguments['cacheTokens']);
+            }
+
+            if (isset($arguments['forceCoversAnnotation'])) {
+                $codeCoverage->setForceCoversAnnotation(
+                  $arguments['forceCoversAnnotation']
+                );
+            }
+
+            if (isset($arguments['mapTestClassNameToCoveredClassName'])) {
+                $codeCoverage->setMapTestClassNameToCoveredClassName(
+                  $arguments['mapTestClassNameToCoveredClassName']
+                );
+            }
+
+            $result->setCodeCoverage($codeCoverage);
         }
 
         if (isset($arguments['jsonLogfile'])) {
@@ -294,6 +302,18 @@ class PHPUnit_TextUI_TestRunner extends PHPUnit_Runner_BaseTestRunner
 
         if ($arguments['strict']) {
             $result->strictMode(TRUE);
+
+            $result->setTimeoutForSmallTests(
+              $arguments['timeoutForSmallTests']
+            );
+
+            $result->setTimeoutForMediumTests(
+              $arguments['timeoutForMediumTests']
+            );
+
+            $result->setTimeoutForLargeTests(
+              $arguments['timeoutForLargeTests']
+            );
         }
 
         $suite->run(
@@ -311,19 +331,25 @@ class PHPUnit_TextUI_TestRunner extends PHPUnit_Runner_BaseTestRunner
             $this->printer->printResult($result);
         }
 
-        if (extension_loaded('tokenizer') && extension_loaded('xdebug')) {
+        if (isset($codeCoverage)) {
+            $title = '';
+
+            if (isset($arguments['configuration'])) {
+                $loggingConfiguration = $arguments['configuration']->getLoggingConfiguration();
+
+                if (isset($loggingConfiguration['title'])) {
+                    $title = $loggingConfiguration['title'];
+                }
+            }
+
             if (isset($arguments['coverageClover'])) {
                 $this->printer->write(
                   "\nWriting code coverage data to XML file, this may take " .
                   'a moment.'
                 );
 
-                require_once 'PHP/CodeCoverage/Report/Clover.php';
-
                 $writer = new PHP_CodeCoverage_Report_Clover;
-                $writer->process(
-                  $result->getCodeCoverage(), $arguments['coverageClover']
-                );
+                $writer->process($codeCoverage, $arguments['coverageClover']);
 
                 $this->printer->write("\n");
                 unset($writer);
@@ -334,60 +360,64 @@ class PHPUnit_TextUI_TestRunner extends PHPUnit_Runner_BaseTestRunner
                   "\nGenerating code coverage report, this may take a moment."
                 );
 
-                $title = '';
-
-                if (isset($arguments['configuration'])) {
-                    $loggingConfiguration = $arguments['configuration']->getLoggingConfiguration();
-
-                    if (isset($loggingConfiguration['title'])) {
-                        $title = $loggingConfiguration['title'];
-                    }
-                }
-
-                require_once 'PHP/CodeCoverage/Report/HTML.php';
-
                 $writer = new PHP_CodeCoverage_Report_HTML(
-                  array(
-                    'title'          => $title,
-                    'charset'        => $arguments['reportCharset'],
-                    'yui'            => $arguments['reportYUI'],
-                    'highlight'      => $arguments['reportHighlight'],
-                    'lowUpperBound'  => $arguments['reportLowUpperBound'],
-                    'highLowerBound' => $arguments['reportHighLowerBound'],
-                    'generator'      => ' and PHPUnit ' . PHPUnit_Runner_Version::id()
-                  )
+                  $title,
+                  $arguments['reportCharset'],
+                  $arguments['reportYUI'],
+                  $arguments['reportHighlight'],
+                  $arguments['reportLowUpperBound'],
+                  $arguments['reportHighLowerBound'],
+                  ' and PHPUnit ' . PHPUnit_Runner_Version::id()
                 );
 
-                $writer->process(
-                  $result->getCodeCoverage(), $arguments['reportDirectory']
-                );
+                $writer->process($codeCoverage, $arguments['reportDirectory']);
 
                 $this->printer->write("\n");
                 unset($writer);
             }
-        }
 
-        $this->pause($arguments['wait']);
+            if (isset($arguments['coveragePHP'])) {
+                $this->printer->write(
+                  "\nSerializing PHP_CodeCoverage object to file, this may take a moment."
+                );
+
+                $writer = new PHP_CodeCoverage_Report_PHP;
+                $writer->process($codeCoverage, $arguments['coveragePHP']);
+
+                $this->printer->write("\n");
+                unset($writer);
+            }
+
+            if (isset($arguments['coverageText'])) {
+                $this->printer->write(
+                  "\nGenerating textual code coverage report, this may take a moment."
+                );
+
+                if ($arguments['coverageText'] == 'php://stdout') {
+                    $outputStream = $this->printer;
+                    $colors       = (bool)$arguments['colors'];
+                } else {
+                    $outputStream = new PHPUnit_Util_Printer($arguments['coverageText']);
+                    $colors       = FALSE;
+                }
+
+                $writer = new PHP_CodeCoverage_Report_Text(
+                  $outputStream,
+                  $title,
+                  $arguments['reportLowUpperBound'],
+                  $arguments['reportHighLowerBound'],
+                  $arguments['coverageTextShowUncoveredFiles']
+                );
+
+                $writer->process($codeCoverage, $colors);
+
+                $this->printer->write("\n");
+            }
+        }
 
         return $result;
     }
 
-    /**
-     * @param  boolean $wait
-     */
-    protected function pause($wait)
-    {
-        if (!$wait) {
-            return;
-        }
-
-        if ($this->printer instanceof PHPUnit_TextUI_ResultPrinter) {
-            $this->printer->printWaitPrompt();
-        }
-
-        fgets(STDIN);
-    }
-
     /**
      * @param  PHPUnit_TextUI_ResultPrinter $resultPrinter
      */
@@ -473,7 +503,6 @@ class PHPUnit_TextUI_TestRunner extends PHPUnit_Runner_BaseTestRunner
         $arguments['debug']     = isset($arguments['debug'])     ? $arguments['debug']     : FALSE;
         $arguments['filter']    = isset($arguments['filter'])    ? $arguments['filter']    : FALSE;
         $arguments['listeners'] = isset($arguments['listeners']) ? $arguments['listeners'] : array();
-        $arguments['wait']      = isset($arguments['wait'])      ? $arguments['wait']      : FALSE;
 
         if (isset($arguments['configuration'])) {
             $arguments['configuration']->handlePHPConfiguration();
@@ -495,6 +524,11 @@ class PHPUnit_TextUI_TestRunner extends PHPUnit_Runner_BaseTestRunner
                 $arguments['bootstrap'] = $phpunitConfiguration['bootstrap'];
             }
 
+            if (isset($phpunitConfiguration['cacheTokens']) &&
+                !isset($arguments['cacheTokens'])) {
+                $arguments['cacheTokens'] = $phpunitConfiguration['cacheTokens'];
+            }
+
             if (isset($phpunitConfiguration['colors']) &&
                 !isset($arguments['colors'])) {
                 $arguments['colors'] = $phpunitConfiguration['colors'];
@@ -525,6 +559,21 @@ class PHPUnit_TextUI_TestRunner extends PHPUnit_Runner_BaseTestRunner
                 $arguments['stopOnFailure'] = $phpunitConfiguration['stopOnFailure'];
             }
 
+            if (isset($phpunitConfiguration['timeoutForSmallTests']) &&
+                !isset($arguments['timeoutForSmallTests'])) {
+                $arguments['timeoutForSmallTests'] = $phpunitConfiguration['timeoutForSmallTests'];
+            }
+
+            if (isset($phpunitConfiguration['timeoutForMediumTests']) &&
+                !isset($arguments['timeoutForMediumTests'])) {
+                $arguments['timeoutForMediumTests'] = $phpunitConfiguration['timeoutForMediumTests'];
+            }
+
+            if (isset($phpunitConfiguration['timeoutForLargeTests']) &&
+                !isset($arguments['timeoutForLargeTests'])) {
+                $arguments['timeoutForLargeTests'] = $phpunitConfiguration['timeoutForLargeTests'];
+            }
+
             if (isset($phpunitConfiguration['strict']) &&
                 !isset($arguments['strict'])) {
                 $arguments['strict'] = $phpunitConfiguration['strict'];
@@ -560,13 +609,7 @@ class PHPUnit_TextUI_TestRunner extends PHPUnit_Runner_BaseTestRunner
             foreach ($arguments['configuration']->getListenerConfiguration() as $listener) {
                 if (!class_exists($listener['class'], FALSE) &&
                     $listener['file'] !== '') {
-                    $file = PHPUnit_Util_Filesystem::fileExistsInIncludePath(
-                      $listener['file']
-                    );
-
-                    if ($file !== FALSE) {
-                        require $file;
-                    }
+                    require_once $listener['file'];
                 }
 
                 if (class_exists($listener['class'], FALSE)) {
@@ -624,6 +667,21 @@ class PHPUnit_TextUI_TestRunner extends PHPUnit_Runner_BaseTestRunner
                 $arguments['coverageClover'] = $loggingConfiguration['coverage-clover'];
             }
 
+            if (isset($loggingConfiguration['coverage-php']) &&
+                !isset($arguments['coveragePHP'])) {
+                $arguments['coveragePHP'] = $loggingConfiguration['coverage-php'];
+            }
+
+            if (isset($loggingConfiguration['coverage-text']) &&
+                !isset($arguments['coverageText'])) {
+                $arguments['coverageText'] = $loggingConfiguration['coverage-text'];
+                if (isset($loggingConfiguration['coverageTextShowUncoveredFiles'])) {
+                    $arguments['coverageTextShowUncoveredFiles'] = $loggingConfiguration['coverageTextShowUncoveredFiles'];
+                } else {
+                    $arguments['coverageTextShowUncoveredFiles'] = FALSE;
+                }
+            }
+
             if (isset($loggingConfiguration['json']) &&
                 !isset($arguments['jsonLogfile'])) {
                 $arguments['jsonLogfile'] = $loggingConfiguration['json'];
@@ -650,16 +708,6 @@ class PHPUnit_TextUI_TestRunner extends PHPUnit_Runner_BaseTestRunner
                 }
             }
 
-            if (isset($loggingConfiguration['story-html']) &&
-                !isset($arguments['storyHTMLFile'])) {
-                $arguments['storyHTMLFile'] = $loggingConfiguration['story-html'];
-            }
-
-            if (isset($loggingConfiguration['story-text']) &&
-                !isset($arguments['storyTextFile'])) {
-                $arguments['storsTextFile'] = $loggingConfiguration['story-text'];
-            }
-
             if (isset($loggingConfiguration['testdox-html']) &&
                 !isset($arguments['testdoxHTMLFile'])) {
                 $arguments['testdoxHTMLFile'] = $loggingConfiguration['testdox-html'];
@@ -669,98 +717,85 @@ class PHPUnit_TextUI_TestRunner extends PHPUnit_Runner_BaseTestRunner
                 !isset($arguments['testdoxTextFile'])) {
                 $arguments['testdoxTextFile'] = $loggingConfiguration['testdox-text'];
             }
-        }
-
-        if (isset($arguments['configuration'])) {
-            $filterConfiguration = $arguments['configuration']->getFilterConfiguration();
-
-            $filter = PHP_CodeCoverage_Filter::getInstance();
-
-            foreach ($filterConfiguration['blacklist']['include']['directory'] as $dir) {
-                $filter->addDirectoryToBlacklist(
-                  $dir['path'], $dir['suffix'], $dir['prefix'], $dir['group']
-                );
-            }
-
-            foreach ($filterConfiguration['blacklist']['include']['file'] as $file) {
-                $filter->addFileToBlacklist($file);
-            }
-
-            foreach ($filterConfiguration['blacklist']['exclude']['directory'] as $dir) {
-                $filter->removeDirectoryFromBlacklist(
-                  $dir['path'], $dir['suffix'], $dir['prefix'], $dir['group']
-                );
-            }
-
-            foreach ($filterConfiguration['blacklist']['exclude']['file'] as $file) {
-                $filter->removeFileFromBlacklist($file);
-            }
 
             if ((isset($arguments['coverageClover']) ||
-                isset($arguments['reportDirectory'])) &&
+                isset($arguments['reportDirectory']) ||
+                isset($arguments['coveragePHP']) ||
+                isset($arguments['coverageText'])) &&
                 extension_loaded('xdebug')) {
-                $coverage = PHP_CodeCoverage::getInstance();
 
-                $coverage->setProcessUncoveredFilesFromWhitelist(
-                  $filterConfiguration['whitelist']['addUncoveredFilesFromWhitelist']
-                );
+                $filterConfiguration = $arguments['configuration']->getFilterConfiguration();
+                $arguments['addUncoveredFilesFromWhitelist'] = $filterConfiguration['whitelist']['addUncoveredFilesFromWhitelist'];
 
-                if (isset($arguments['forceCoversAnnotation'])) {
-                    $coverage->setForceCoversAnnotation(
-                      $arguments['forceCoversAnnotation']
+                foreach ($filterConfiguration['blacklist']['include']['directory'] as $dir) {
+                    $this->codeCoverageFilter->addDirectoryToBlacklist(
+                      $dir['path'], $dir['suffix'], $dir['prefix'], $dir['group']
                     );
                 }
 
-                if (isset($arguments['mapTestClassNameToCoveredClassName'])) {
-                    $coverage->setMapTestClassNameToCoveredClassName(
-                      $arguments['mapTestClassNameToCoveredClassName']
+                foreach ($filterConfiguration['blacklist']['include']['file'] as $file) {
+                    $this->codeCoverageFilter->addFileToBlacklist($file);
+                }
+
+                foreach ($filterConfiguration['blacklist']['exclude']['directory'] as $dir) {
+                    $this->codeCoverageFilter->removeDirectoryFromBlacklist(
+                      $dir['path'], $dir['suffix'], $dir['prefix'], $dir['group']
                     );
                 }
 
+                foreach ($filterConfiguration['blacklist']['exclude']['file'] as $file) {
+                    $this->codeCoverageFilter->removeFileFromBlacklist($file);
+                }
+
                 foreach ($filterConfiguration['whitelist']['include']['directory'] as $dir) {
-                    $filter->addDirectoryToWhitelist(
+                    $this->codeCoverageFilter->addDirectoryToWhitelist(
                       $dir['path'], $dir['suffix'], $dir['prefix']
                     );
                 }
 
                 foreach ($filterConfiguration['whitelist']['include']['file'] as $file) {
-                    $filter->addFileToWhitelist($file);
+                    $this->codeCoverageFilter->addFileToWhitelist($file);
                 }
 
                 foreach ($filterConfiguration['whitelist']['exclude']['directory'] as $dir) {
-                    $filter->removeDirectoryFromWhitelist(
+                    $this->codeCoverageFilter->removeDirectoryFromWhitelist(
                       $dir['path'], $dir['suffix'], $dir['prefix']
                     );
                 }
 
                 foreach ($filterConfiguration['whitelist']['exclude']['file'] as $file) {
-                    $filter->removeFileFromWhitelist($file);
+                    $this->codeCoverageFilter->removeFileFromWhitelist($file);
                 }
             }
         }
 
-        $arguments['backupGlobals']               = isset($arguments['backupGlobals'])               ? $arguments['backupGlobals']               : NULL;
-        $arguments['backupStaticAttributes']      = isset($arguments['backupStaticAttributes'])      ? $arguments['backupStaticAttributes']      : NULL;
-        $arguments['colors']                      = isset($arguments['colors'])                      ? $arguments['colors']                      : FALSE;
-        $arguments['convertErrorsToExceptions']   = isset($arguments['convertErrorsToExceptions'])   ? $arguments['convertErrorsToExceptions']   : TRUE;
-        $arguments['convertNoticesToExceptions']  = isset($arguments['convertNoticesToExceptions'])  ? $arguments['convertNoticesToExceptions']  : TRUE;
-        $arguments['convertWarningsToExceptions'] = isset($arguments['convertWarningsToExceptions']) ? $arguments['convertWarningsToExceptions'] : TRUE;
-        $arguments['excludeGroups']               = isset($arguments['excludeGroups'])               ? $arguments['excludeGroups']               : array();
-        $arguments['groups']                      = isset($arguments['groups'])                      ? $arguments['groups']                      : array();
-        $arguments['logIncompleteSkipped']        = isset($arguments['logIncompleteSkipped'])        ? $arguments['logIncompleteSkipped']        : FALSE;
-        $arguments['processIsolation']            = isset($arguments['processIsolation'])            ? $arguments['processIsolation']            : FALSE;
-        $arguments['repeat']                      = isset($arguments['repeat'])                      ? $arguments['repeat']                      : FALSE;
-        $arguments['reportCharset']               = isset($arguments['reportCharset'])               ? $arguments['reportCharset']               : 'UTF-8';
-        $arguments['reportHighlight']             = isset($arguments['reportHighlight'])             ? $arguments['reportHighlight']             : FALSE;
-        $arguments['reportHighLowerBound']        = isset($arguments['reportHighLowerBound'])        ? $arguments['reportHighLowerBound']        : 70;
-        $arguments['reportLowUpperBound']         = isset($arguments['reportLowUpperBound'])         ? $arguments['reportLowUpperBound']         : 35;
-        $arguments['reportYUI']                   = isset($arguments['reportYUI'])                   ? $arguments['reportYUI']                   : TRUE;
-        $arguments['stopOnError']                 = isset($arguments['stopOnError'])                 ? $arguments['stopOnError']                 : FALSE;
-        $arguments['stopOnFailure']               = isset($arguments['stopOnFailure'])               ? $arguments['stopOnFailure']               : FALSE;
-        $arguments['stopOnIncomplete']            = isset($arguments['stopOnIncomplete'])            ? $arguments['stopOnIncomplete']            : FALSE;
-        $arguments['stopOnSkipped']               = isset($arguments['stopOnSkipped'])               ? $arguments['stopOnSkipped']               : FALSE;
-        $arguments['strict']                      = isset($arguments['strict'])                      ? $arguments['strict']                      : FALSE;
-        $arguments['verbose']                     = isset($arguments['verbose'])                     ? $arguments['verbose']                     : FALSE;
+        $arguments['addUncoveredFilesFromWhitelist'] = isset($arguments['addUncoveredFilesFromWhitelist']) ? $arguments['addUncoveredFilesFromWhitelist'] : TRUE;
+        $arguments['backupGlobals']                  = isset($arguments['backupGlobals'])                  ? $arguments['backupGlobals']                  : NULL;
+        $arguments['backupStaticAttributes']         = isset($arguments['backupStaticAttributes'])         ? $arguments['backupStaticAttributes']         : NULL;
+        $arguments['cacheTokens']                    = isset($arguments['cacheTokens'])                    ? $arguments['cacheTokens']                    : TRUE;
+        $arguments['colors']                         = isset($arguments['colors'])                         ? $arguments['colors']                         : FALSE;
+        $arguments['convertErrorsToExceptions']      = isset($arguments['convertErrorsToExceptions'])      ? $arguments['convertErrorsToExceptions']      : TRUE;
+        $arguments['convertNoticesToExceptions']     = isset($arguments['convertNoticesToExceptions'])     ? $arguments['convertNoticesToExceptions']     : TRUE;
+        $arguments['convertWarningsToExceptions']    = isset($arguments['convertWarningsToExceptions'])    ? $arguments['convertWarningsToExceptions']    : TRUE;
+        $arguments['excludeGroups']                  = isset($arguments['excludeGroups'])                  ? $arguments['excludeGroups']                  : array();
+        $arguments['groups']                         = isset($arguments['groups'])                         ? $arguments['groups']                         : array();
+        $arguments['logIncompleteSkipped']           = isset($arguments['logIncompleteSkipped'])           ? $arguments['logIncompleteSkipped']           : FALSE;
+        $arguments['processIsolation']               = isset($arguments['processIsolation'])               ? $arguments['processIsolation']               : FALSE;
+        $arguments['repeat']                         = isset($arguments['repeat'])                         ? $arguments['repeat']                         : FALSE;
+        $arguments['reportCharset']                  = isset($arguments['reportCharset'])                  ? $arguments['reportCharset']                  : 'UTF-8';
+        $arguments['reportHighlight']                = isset($arguments['reportHighlight'])                ? $arguments['reportHighlight']                : FALSE;
+        $arguments['reportHighLowerBound']           = isset($arguments['reportHighLowerBound'])           ? $arguments['reportHighLowerBound']           : 70;
+        $arguments['reportLowUpperBound']            = isset($arguments['reportLowUpperBound'])            ? $arguments['reportLowUpperBound']            : 35;
+        $arguments['reportYUI']                      = isset($arguments['reportYUI'])                      ? $arguments['reportYUI']                      : TRUE;
+        $arguments['stopOnError']                    = isset($arguments['stopOnError'])                    ? $arguments['stopOnError']                    : FALSE;
+        $arguments['stopOnFailure']                  = isset($arguments['stopOnFailure'])                  ? $arguments['stopOnFailure']                  : FALSE;
+        $arguments['stopOnIncomplete']               = isset($arguments['stopOnIncomplete'])               ? $arguments['stopOnIncomplete']               : FALSE;
+        $arguments['stopOnSkipped']                  = isset($arguments['stopOnSkipped'])                  ? $arguments['stopOnSkipped']                  : FALSE;
+        $arguments['timeoutForSmallTests']           = isset($arguments['timeoutForSmallTests'])           ? $arguments['timeoutForSmallTests']           : 1;
+        $arguments['timeoutForMediumTests']          = isset($arguments['timeoutForMediumTests'])          ? $arguments['timeoutForMediumTests']          : 10;
+        $arguments['timeoutForLargeTests']           = isset($arguments['timeoutForLargeTests'])           ? $arguments['timeoutForLargeTests']           : 60;
+        $arguments['strict']                         = isset($arguments['strict'])                         ? $arguments['strict']                         : FALSE;
+        $arguments['verbose']                        = isset($arguments['verbose'])                        ? $arguments['verbose']                        : FALSE;
 
         if ($arguments['filter'] !== FALSE &&
             preg_match('/^[a-zA-Z0-9_]/', $arguments['filter'])) {
