@@ -2,7 +2,7 @@
 /**
  * PHPUnit
  *
- * Copyright (c) 2002-2010, Sebastian Bergmann <sebastian@phpunit.de>.
+ * Copyright (c) 2001-2012, Sebastian Bergmann <sebastian@phpunit.de>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,7 +37,7 @@
  * @package    PHPUnit
  * @subpackage Util_Log
  * @author     Sebastian Bergmann <sebastian@phpunit.de>
- * @copyright  2002-2010 Sebastian Bergmann <sebastian@phpunit.de>
+ * @copyright  2001-2012 Sebastian Bergmann <sebastian@phpunit.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
  * @link       http://www.phpunit.de/
  * @since      File available since Release 2.3.0
@@ -51,9 +51,9 @@
  * @package    PHPUnit
  * @subpackage Util_Log
  * @author     Sebastian Bergmann <sebastian@phpunit.de>
- * @copyright  2002-2010 Sebastian Bergmann <sebastian@phpunit.de>
+ * @copyright  2001-2012 Sebastian Bergmann <sebastian@phpunit.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.5.5
+ * @version    Release: 3.6.10
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 2.1.0
  */
@@ -174,7 +174,7 @@ class PHPUnit_Util_Log_JUnit extends PHPUnit_Util_Printer implements PHPUnit_Fra
 
             $buffer .= PHPUnit_Framework_TestFailure::exceptionToString($e) .
                        "\n" .
-                       PHPUnit_Util_Filter::getFilteredStacktrace($e, FALSE);
+                       PHPUnit_Util_Filter::getFilteredStacktrace($e);
 
             $error = $this->document->createElement(
               'error', PHPUnit_Util_XML::prepareString($buffer)
@@ -205,11 +205,9 @@ class PHPUnit_Util_Log_JUnit extends PHPUnit_Util_Printer implements PHPUnit_Fra
                     $buffer = '';
                 }
 
-                $buffer .= PHPUnit_Framework_TestFailure::exceptionToString($e).
+                $buffer .= PHPUnit_Framework_TestFailure::exceptionToString($e) .
                            "\n" .
-                           PHPUnit_Util_Filter::getFilteredStacktrace(
-                             $e, FALSE
-                           );
+                           PHPUnit_Util_Filter::getFilteredStacktrace($e);
 
                 $failure = $this->document->createElement(
                   'failure', PHPUnit_Util_XML::prepareString($buffer)
@@ -238,7 +236,7 @@ class PHPUnit_Util_Log_JUnit extends PHPUnit_Util_Printer implements PHPUnit_Fra
               'error',
               PHPUnit_Util_XML::prepareString(
                 "Incomplete Test\n" .
-                PHPUnit_Util_Filter::getFilteredStacktrace($e, FALSE)
+                PHPUnit_Util_Filter::getFilteredStacktrace($e)
               )
             );
 
@@ -267,7 +265,7 @@ class PHPUnit_Util_Log_JUnit extends PHPUnit_Util_Printer implements PHPUnit_Fra
               'error',
               PHPUnit_Util_XML::prepareString(
                 "Skipped Test\n" .
-                PHPUnit_Util_Filter::getFilteredStacktrace($e, FALSE)
+                PHPUnit_Util_Filter::getFilteredStacktrace($e)
               )
             );
 
