@@ -2,7 +2,7 @@
 /**
  * PHPUnit
  *
- * Copyright (c) 2002-2010, Sebastian Bergmann <sebastian@phpunit.de>.
+ * Copyright (c) 2001-2012, Sebastian Bergmann <sebastian@phpunit.de>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,7 +37,7 @@
  * @package    PHPUnit
  * @subpackage Util
  * @author     Sebastian Bergmann <sebastian@phpunit.de>
- * @copyright  2002-2010 Sebastian Bergmann <sebastian@phpunit.de>
+ * @copyright  2001-2012 Sebastian Bergmann <sebastian@phpunit.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
  * @link       http://www.phpunit.de/
  * @since      File available since Release 3.4.0
@@ -49,31 +49,18 @@
  * @package    PHPUnit
  * @subpackage Util
  * @author     Sebastian Bergmann <sebastian@phpunit.de>
- * @copyright  2002-2010 Sebastian Bergmann <sebastian@phpunit.de>
+ * @copyright  2001-2012 Sebastian Bergmann <sebastian@phpunit.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
  * @version    Release: @package_version@
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 3.4.0
  */
-class PHPUnit_Util_PHP
+abstract class PHPUnit_Util_PHP
 {
     /**
-     * Path to the PHP interpreter that is to be used.
-     *
-     * @var    string $phpBinary
+     * @var string $phpBinary
      */
-    protected static $phpBinary = NULL;
-
-    /**
-     * Descriptor specification for proc_open().
-     *
-     * @var    array
-     */
-    protected static $descriptorSpec = array(
-      0 => array('pipe', 'r'),
-      1 => array('pipe', 'w'),
-      2 => array('pipe', 'w')
-    );
+    protected $phpBinary;
 
     /**
      * Returns the path to a PHP interpreter.
@@ -83,48 +70,82 @@ class PHPUnit_Util_PHP
      *
      * When not set, the following assumptions will be made:
      *
-     *   1. When the PHP CLI/CGI binary configured with the PEAR Installer
-     *      (php_bin configuration value) is readable, it will be used.
-     *
-     *   2. When PHPUnit is run using the CLI SAPI and the $_SERVER['_']
+     *   1. When PHPUnit is run using the CLI SAPI and the $_SERVER['_']
      *      variable does not contain the string "PHPUnit", $_SERVER['_']
      *      is assumed to contain the path to the current PHP interpreter
      *      and that will be used.
      *
-     *   3. When PHPUnit is run using the CLI SAPI and the $_SERVER['_']
+     *   2. When PHPUnit is run using the CLI SAPI and the $_SERVER['_']
      *      variable contains the string "PHPUnit", the file that $_SERVER['_']
      *      points to is assumed to be the PHPUnit TextUI CLI wrapper script
      *      "phpunit" and the binary set up using #! on that file's first
      *      line of code is assumed to contain the path to the current PHP
      *      interpreter and that will be used.
      *
+     *   3. When the PHP CLI/CGI binary configured with the PEAR Installer
+     *      (php_bin configuration value) is readable, it will be used.
+     *
      *   4. The current PHP interpreter is assumed to be in the $PATH and
      *      to be invokable through "php".
      *
      * @return string
      */
-    public static function getPhpBinary()
+    protected function getPhpBinary()
     {
-        if (self::$phpBinary === NULL) {
-            if (is_readable('@php_bin@')) {
-                self::$phpBinary = '@php_bin@';
+        if ($this->phpBinary === NULL) {
+            if (defined("PHP_BINARY")) {
+                $this->phpBinary = PHP_BINARY;
+            } else if (PHP_SAPI == 'cli' && isset($_SERVER['_'])) {
+                if (strpos($_SERVER['_'], 'phpunit') !== FALSE) {
+                    $file = file($_SERVER['_']);
+
+                    if (strpos($file[0], ' ') !== FALSE) {
+                        $tmp = explode(' ', $file[0]);
+                        $this->phpBinary = trim($tmp[1]);
+                    } else {
+                        $this->phpBinary = ltrim(trim($file[0]), '#!');
+                    }
+                } else if (strpos(basename($_SERVER['_']), 'php') !== FALSE) {
+                    $this->phpBinary = $_SERVER['_'];
+                }
             }
 
-            else if (PHP_SAPI == 'cli' && isset($_SERVER['_']) &&
-                     strpos($_SERVER['_'], 'phpunit') !== FALSE) {
-                $file            = file($_SERVER['_']);
-                $tmp             = explode(' ', $file[0]);
-                self::$phpBinary = trim($tmp[1]);
+            if ($this->phpBinary === NULL) {
+                $possibleBinaryLocations = array(
+                    PHP_BINDIR . '/php',
+                    PHP_BINDIR . '/php-cli.exe',
+                    PHP_BINDIR . '/php.exe',
+                    '@php_bin@',
+                );
+                foreach ($possibleBinaryLocations as $binary) {
+                    if (is_readable($binary)) {
+                        $this->phpBinary = $binary;
+                        break;
+                    }
+                }
             }
 
-            if (!is_readable(self::$phpBinary)) {
-                self::$phpBinary = 'php';
+            if (!is_readable($this->phpBinary)) {
+                $this->phpBinary = 'php';
             } else {
-                self::$phpBinary = escapeshellarg(self::$phpBinary);
+                $this->phpBinary = escapeshellcmd($this->phpBinary);
             }
         }
 
-        return self::$phpBinary;
+        return $this->phpBinary;
+    }
+
+    /**
+     * @return PHPUnit_Util_PHP
+     * @since  Method available since Release 3.5.12
+     */
+    public static function factory()
+    {
+        if (DIRECTORY_SEPARATOR == '\\') {
+            return new PHPUnit_Util_PHP_Windows;
+        }
+
+        return new PHPUnit_Util_PHP_Default;
     }
 
     /**
@@ -134,44 +155,65 @@ class PHPUnit_Util_PHP
      * @param  PHPUnit_Framework_TestCase   $test
      * @param  PHPUnit_Framework_TestResult $result
      * @return array|null
+     * @throws PHPUnit_Framework_Exception
      */
-    public static function runJob($job, PHPUnit_Framework_Test $test = NULL, PHPUnit_Framework_TestResult $result = NULL)
+    public function runJob($job, PHPUnit_Framework_Test $test = NULL, PHPUnit_Framework_TestResult $result = NULL)
     {
         $process = proc_open(
-          self::getPhpBinary(), self::$descriptorSpec, $pipes
+          $this->getPhpBinary(),
+          array(
+            0 => array('pipe', 'r'),
+            1 => array('pipe', 'w'),
+            2 => array('pipe', 'w')
+          ),
+          $pipes
         );
 
-        // Workaround for http://bugs.php.net/bug.php?id=52911
-        if (DIRECTORY_SEPARATOR == '\\') {
-            sleep(2);
+        if (!is_resource($process)) {
+            throw new PHPUnit_Framework_Exception(
+              'Unable to create process for process isolation.'
+            );
         }
 
-        if (is_resource($process)) {
-            if ($result !== NULL) {
-                $result->startTest($test);
-            }
+        if ($result !== NULL) {
+            $result->startTest($test);
+        }
 
-            fwrite($pipes[0], $job);
-            fclose($pipes[0]);
+        $this->process($pipes[0], $job);
+        fclose($pipes[0]);
 
-            $stdout = stream_get_contents($pipes[1]);
-            fclose($pipes[1]);
+        $stdout = stream_get_contents($pipes[1]);
+        fclose($pipes[1]);
 
-            $stderr = stream_get_contents($pipes[2]);
-            fclose($pipes[2]);
+        $stderr = stream_get_contents($pipes[2]);
+        fclose($pipes[2]);
 
-            proc_close($process);
+        proc_close($process);
+        $this->cleanup();
 
-            if ($result !== NULL) {
-                self::processChildResult($test, $result, $stdout, $stderr);
-            } else {
-                return array('stdout' => $stdout, 'stderr' => $stderr);
-            }
+        if ($result !== NULL) {
+            $this->processChildResult($test, $result, $stdout, $stderr);
+        } else {
+            return array('stdout' => $stdout, 'stderr' => $stderr);
         }
     }
 
     /**
-     * Runs a single job (PHP code) using a separate PHP process.
+     * @param resource $pipe
+     * @param string   $job
+     * @since Method available since Release 3.5.12
+     */
+    abstract protected function process($pipe, $job);
+
+    /**
+     * @since Method available since Release 3.5.12
+     */
+    protected function cleanup()
+    {
+    }
+
+    /**
+     * Processes the TestResult object from an isolated process.
      *
      * @param PHPUnit_Framework_TestCase   $test
      * @param PHPUnit_Framework_TestResult $result
@@ -179,7 +221,7 @@ class PHPUnit_Util_PHP
      * @param string                       $stderr
      * @since Method available since Release 3.5.0
      */
-    protected static function processChildResult(PHPUnit_Framework_Test $test, PHPUnit_Framework_TestResult $result, $stdout, $stderr)
+    protected function processChildResult(PHPUnit_Framework_Test $test, PHPUnit_Framework_TestResult $result, $stdout, $stderr)
     {
         if (!empty($stderr)) {
             $time = 0;
@@ -201,14 +243,9 @@ class PHPUnit_Util_PHP
                 $childResult = $childResult['result'];
 
                 if ($result->getCollectCodeCoverageInformation()) {
-                    $codeCoverageInformation = $childResult->getRawCodeCoverageInformation();
-
-                    if (isset($codeCoverageInformation[0]) &&
-                         is_array($codeCoverageInformation[0])) {
-                        $result->getCodeCoverage()->append(
-                          $codeCoverageInformation[0], $test
-                        );
-                    }
+                    $result->getCodeCoverage()->merge(
+                      $childResult->getCodeCoverage()
+                    );
                 }
 
                 $time           = $childResult->time();
@@ -219,25 +256,25 @@ class PHPUnit_Util_PHP
 
                 if (!empty($notImplemented)) {
                     $result->addError(
-                      $test, $notImplemented[0]->thrownException(), $time
+                      $test, $this->getException($notImplemented[0]), $time
                     );
                 }
 
                 else if (!empty($skipped)) {
                     $result->addError(
-                      $test, $skipped[0]->thrownException(), $time
+                      $test, $this->getException($skipped[0]), $time
                     );
                 }
 
                 else if (!empty($errors)) {
                     $result->addError(
-                      $test, $errors[0]->thrownException(), $time
+                      $test, $this->getException($errors[0]), $time
                     );
                 }
 
                 else if (!empty($failures)) {
                     $result->addFailure(
-                      $test, $failures[0]->thrownException(), $time
+                      $test, $this->getException($failures[0]), $time
                     );
                 }
             } else {
@@ -251,4 +288,38 @@ class PHPUnit_Util_PHP
 
         $result->endTest($test, $time);
     }
+
+    /**
+     * Gets the thrown exception from a PHPUnit_Framework_TestFailure.
+     *
+     * @param PHPUnit_Framework_TestFailure $error
+     * @since Method available since Release 3.6.0
+     * @see   https://github.com/sebastianbergmann/phpunit/issues/74
+     */
+    protected function getException(PHPUnit_Framework_TestFailure $error)
+    {
+        $exception = $error->thrownException();
+
+        if ($exception instanceof __PHP_Incomplete_Class) {
+            $exceptionArray = array();
+            foreach ((array)$exception as $key => $value) {
+                $key = substr($key, strrpos($key, "\0") + 1);
+                $exceptionArray[$key] = $value;
+            }
+
+            $exception = new PHPUnit_Framework_SyntheticError(
+              sprintf(
+                '%s: %s',
+                $exceptionArray['_PHP_Incomplete_Class_Name'],
+                $exceptionArray['message']
+              ),
+              $exceptionArray['code'],
+              $exceptionArray['file'],
+              $exceptionArray['line'],
+              $exceptionArray['trace']
+            );
+        }
+
+        return $exception;
+    }
 }
